process_record

Function process_record 

pub async fn process_record(
    message: &SqsMessage,
    working_directory: PathBuf,
    s3_endpoint_url: Option<&str>,
    sqs_endpoint_url: Option<&str>,
) -> Result<PathBuf, Error>
Processes the SQS message.

This will download the file specified in the message body, anonymise it, upload it to S3 and send the message on to the output queue.